@@ -111,7 +111,7 @@ def Pyomo2FD_expression(exp, ipoint, vars, symbol_map):
     elif isinstance(exp, expr._IdentityExpression):
         return Pyomo2FD_expression(exp._args[0], ipoint, vars, symbol_map)
 
-    elif (isinstance(exp,var._VarData) or isinstance(exp,var.Var)) and not exp.fixed_value():
+    elif (isinstance(exp,var._VarData) or isinstance(exp,var.Var)) and not exp.is_fixed():
         vname = symbol_map.getSymbol(exp, labeler)
         if not vname in vars:
             vars[vname] = FuncDesigner.oovar(vname)
@@ -125,7 +125,7 @@ def Pyomo2FD_expression(exp, ipoint, vars, symbol_map):
     elif type(exp) in [int, float, long]:
         return exp
 
-    elif isinstance(exp,numvalue.NumericConstant) or exp.fixed_value:
+    elif isinstance(exp,numvalue.NumericConstant) or exp.is_fixed():
         return exp.value
 
     else:
